@@ -1,12 +1,17 @@
+from __future__ import annotations
+
+import math
 import re
 
 import numpy as np
 from tlz import concat, merge, unique
 
+from dask.array._shuffle import _calculate_new_chunksizes
 from dask.array.core import Array, apply_infer_dtype, asarray, blockwise, getitem
 from dask.array.utils import meta_from_array
 from dask.core import flatten
 from dask.highlevelgraph import HighLevelGraph
+from dask.utils import cached_max
 
 # Modified version of `numpy.lib.function_base._parse_gufunc_signature`
 # Modifications:
@@ -111,7 +116,7 @@ def _validate_normalize_axes(axes, axis, keepdims, input_coredimss, output_cored
                         "To use `axis`, all core dimensions have to be equal"
                     )
 
-    # Expand dafaults or axis
+    # Expand defaults or axis
     if axes is None:
         if axis is not None:
             axes = [(axis,) if cd else tuple() for cd in core_dims]
@@ -382,7 +387,7 @@ def apply_gufunc(
 
     ## Axes: transpose input arguments
     transposed_args = []
-    for arg, iax, input_coredims in zip(args, input_axes, input_coredimss):
+    for arg, iax in zip(args, input_axes):
         shape = arg.shape
         iax = tuple(a if a < 0 else a - len(shape) for a in iax)
         tidc = tuple(i for i in range(-len(shape) + 0, 0) if i not in iax) + iax
@@ -447,6 +452,30 @@ significantly.".format(
                     f"Dimension `'{dim}'` with different chunksize present"
                 )
 
+    if allow_rechunk:
+        new_args = []
+        for a, dims in zip(args, input_dimss):
+            factor = 1
+            changeable_dimensions = set()
+            for i, d in enumerate(dims):
+                if d not in loop_output_dims:
+                    # This will be rechunked to -1
+                    factor *= a.shape[i] / max(a.chunks[i])
+                elif max(a.chunks[i]) > 1:
+                    # Dimensions that we can reduce to compensate for the increase
+                    changeable_dimensions.add(i)
+            if factor > 1 and len(changeable_dimensions) > 0:
+                result = _calculate_new_chunksizes(
+                    a.chunks,
+                    list(a.chunks),
+                    changeable_dimensions,
+                    math.prod(map(cached_max, a.chunks)) / factor,
+                )
+                new_args.append(a.rechunk(result))
+            else:
+                new_args.append(a)
+        args = new_args
+
     ## Apply function - use blockwise here
     arginds = list(concat(zip(args, input_dimss)))
 
