@@ -1,11 +1,12 @@
 from __future__ import annotations
 
-from dask._task_spec import DataNode, GraphNode, List, Task, TaskRef
+from dask._task_spec import Alias, DataNode, GraphNode, List, Task, TaskRef
 
 __all__ = [
     "DataNode",
     "Task",
     "TaskRef",
+    "Alias",
     "GraphNode",
     "List",
 ]
